/* Generated by re2c 0.9.3 on Tue Apr 12 21:11:14 2005 */
#line 1 "token.re"
/*
 * token.re
 *
 * $Author: why $
 * $Date: 2005/04/13 06:27:54 $
 *
 * Copyright (C) 2003 why the lucky stiff
 */
#include "syck.h"
#include "gram.h"

/*
 * Allocate quoted strings in chunks
 */
#define QUOTELEN    1024

/*
 * They do my bidding...
 */
#define YYCTYPE     char
#define YYCURSOR    parser->cursor
#define YYMARKER    parser->marker
#define YYLIMIT     parser->limit
#define YYTOKEN     parser->token
#define YYTOKTMP    parser->toktmp
#define YYLINEPTR   parser->lineptr
#define YYLINECTPTR parser->linectptr
#define YYLINE      parser->linect
#define YYFILL(n)   syck_parser_read(parser)

/*
 * Repositions the cursor at `n' offset from the token start.
 * Only works in `Header' and `Document' sections.
 */
#define YYPOS(n)    YYCURSOR = YYTOKEN + n

/*
 * Track line numbers
 */
#define NEWLINE(ptr)    YYLINEPTR = ptr + newline_len(ptr); if ( YYLINEPTR > YYLINECTPTR ) { YYLINE++; YYLINECTPTR = YYLINEPTR; }

/*
 * I like seeing the level operations as macros...
 */
#define ADD_LEVEL(len, status)  syck_parser_add_level( parser, len, status )
#define POP_LEVEL()     syck_parser_pop_level( parser )
#define CURRENT_LEVEL() syck_parser_current_level( parser )

/*
 * Force a token next time around sycklex()
 */
#define FORCE_NEXT_TOKEN(tok)    parser->force_token = tok;

/*
 * Nice little macro to ensure we're YAML_IOPENed to the current level.
 * * Only use this macro in the "Document" section *
 */
#define ENSURE_YAML_IOPEN(last_lvl, to_len, reset) \
        if ( last_lvl->spaces < to_len ) \
        { \
            if ( last_lvl->status == syck_lvl_iseq || last_lvl->status == syck_lvl_imap ) \
            { \
                goto Document; \
            } \
            else \
            { \
                ADD_LEVEL( to_len, syck_lvl_doc ); \
                if ( reset == 1 ) YYPOS(0); \
                return YAML_IOPEN; \
            } \
        } 

/*
 * Nice little macro to ensure closure of levels.
 * * Only use this macro in the "Document" section *
 */
#define ENSURE_YAML_IEND(last_lvl, to_len) \
        if ( last_lvl->spaces > to_len ) \
        { \
            syck_parser_pop_level( parser ); \
            YYPOS(0); \
            return YAML_IEND; \
        }

/*
 * Concatenates quoted string items and manages allocation
 * to the quoted string
 */
#define QUOTECAT(s, c, i, l) \
        { \
            if ( i + 1 >= c ) \
            { \
                c += QUOTELEN; \
                S_REALLOC_N( s, char, c ); \
            } \
            s[i++] = l; \
            s[i] = '\0'; \
        }

#define QUOTECATS(s, c, i, cs, cl) \
        { \
            while ( i + cl >= c ) \
            { \
                c += QUOTELEN; \
                S_REALLOC_N( s, char, c ); \
            } \
            S_MEMCPY( s + i, cs, char, cl ); \
            i += cl; \
            s[i] = '\0'; \
        }

/*
 * Tags a plain scalar with a transfer method
 * * Use only in "Plain" section *
 */
#define RETURN_IMPLICIT() \
    { \
        SyckNode *n = syck_alloc_str(); \
        YYCURSOR = YYTOKEN; \
        n->data.str->ptr = qstr; \
        n->data.str->len = qidx; \
        n->data.str->style = scalar_plain; \
        sycklval->nodeData = n; \
        if ( parser->implicit_typing == 1 ) \
        { \
            try_tag_implicit( sycklval->nodeData, parser->taguri_expansion ); \
        } \
        return YAML_PLAIN; \
    }

/* concat the inline characters to the plain scalar */
#define PLAIN_NOT_INL() \
    if ( *(YYCURSOR - 1) == ' ' || is_newline( YYCURSOR - 1 ) ) \
    { \
        YYCURSOR--; \
    } \
    QUOTECATS(qstr, qcapa, qidx, YYTOKEN, YYCURSOR - YYTOKEN); \
    goto Plain2;

/* trim spaces off the end in case of indent */
#define PLAIN_IS_INL() \
    char *walker = qstr + qidx - 1; \
    while ( walker > qstr && ( *walker == '\n' || *walker == ' ' ) ) \
    { \
        qidx--; \
        walker[0] = '\0'; \
        walker--; \
    }

/*
 * Keep or chomp block?
 * * Use only in "ScalarBlock" section *
 */
#define RETURN_YAML_BLOCK() \
    { \
        SyckNode *n = syck_alloc_str(); \
        if ( ((SyckParser *)parser)->taguri_expansion == 1 ) \
        { \
            n->type_id = syck_taguri( YAML_DOMAIN, "str", 3 ); \
        } \
        else \
        { \
            n->type_id = syck_strndup( "str", 3 ); \
        } \
        n->data.str->ptr = qstr; \
        n->data.str->len = qidx; \
        if ( blockType == BLOCK_LIT ) { \
            n->data.str->style = scalar_literal; \
        } else { \
            n->data.str->style = scalar_fold; \
        } \
        if ( qidx > 0 ) \
        { \
            if ( nlDoWhat != NL_KEEP ) \
            { \
                char *fc = n->data.str->ptr + n->data.str->len - 1; \
                while ( is_newline( fc ) ) fc--; \
                if ( nlDoWhat != NL_CHOMP && fc < n->data.str->ptr + n->data.str->len - 1 ) \
                    fc += 1; \
                n->data.str->len = fc - n->data.str->ptr + 1; \
            } \
        } \
        sycklval->nodeData = n; \
        return YAML_BLOCK; \
    }

/*
 * Handles newlines, calculates indent
 */
#define GOBBLE_UP_YAML_INDENT( ict, start ) \
    char *indent = start; \
    NEWLINE(indent); \
    while ( indent < YYCURSOR ) \
    { \
        if ( is_newline( ++indent ) ) \
        { \
            NEWLINE(indent); \
        } \
    } \
    ict = 0; \
    if ( *YYCURSOR == '\0' ) \
    { \
        ict = -1; \
        start = YYCURSOR - 1; \
    } \
    else if ( *YYLINEPTR == ' ' ) \
    { \
        ict = YYCURSOR - YYLINEPTR; \
    }

/*
 * If an indent exists at the current level, back up.
 */
#define GET_TRUE_YAML_INDENT(indt_len) \
    { \
        SyckLevel *lvl_deep = CURRENT_LEVEL(); \
        indt_len = lvl_deep->spaces; \
        if ( indt_len == YYTOKEN - YYLINEPTR ) \
        { \
            SyckLevel *lvl_over; \
            parser->lvl_idx--; \
            lvl_over = CURRENT_LEVEL(); \
            indt_len = lvl_over->spaces; \
            parser->lvl_idx++; \
        } \
    }

/*
 * Argjh!  I hate globals!  Here for syckerror() only!
 */
SyckParser *syck_parser_ptr = NULL;

/*
 * Accessory funcs later in this file.
 */
void eat_comments( SyckParser * );
char escape_seq( char );
int is_newline( char *ptr );
int newline_len( char *ptr );
int sycklex_yaml_utf8( YYSTYPE *, SyckParser * );
int sycklex_bytecode_utf8( YYSTYPE *, SyckParser * );
int syckwrap();

/*
 * My own re-entrant sycklex() using re2c.
 * You really get used to the limited regexp.
 * It's really nice to not rely on backtracking and such.
 */
int
sycklex( YYSTYPE *sycklval, SyckParser *parser )
{
    switch ( parser->input_type )
    {
        case syck_yaml_utf8:
        return sycklex_yaml_utf8( sycklval, parser );

        case syck_yaml_utf16:
            syckerror( "UTF-16 is not currently supported in Syck.\nPlease contribute code to help this happen!" );
        break;

        case syck_yaml_utf32:
            syckerror( "UTF-32 is not currently supported in Syck.\nPlease contribute code to help this happen!" );
        break;

        case syck_bytecode_utf8:
        return sycklex_bytecode_utf8( sycklval, parser );
    }
}

/*
 * Parser for standard YAML [UTF-8]
 */
int
sycklex_yaml_utf8( YYSTYPE *sycklval, SyckParser *parser )
{
    int doc_level = 0;
    syck_parser_ptr = parser;
    if ( YYCURSOR == NULL ) 
    {
        syck_parser_read( parser );
    }

    if ( parser->force_token != 0 )
    {
        int t = parser->force_token;
        parser->force_token = 0;
        return t;
    }

#line 312 "token.re"


    if ( YYLINEPTR != YYCURSOR )
    {
        goto Document;
    }

Header:

    YYTOKEN = YYCURSOR;


#line 7 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy0;
yy1:    ++YYCURSOR;
yy0:
        if((YYLIMIT - YYCURSOR) < 5) YYFILL(5);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy7;
        case '\n':      goto yy9;
        case '\r':      goto yy11;
        case ' ':       goto yy12;
        case '#':       goto yy5;
        case '-':       goto yy2;
        case '.':       goto yy4;
        default:        goto yy14;
        }
yy2:    yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '-':       goto yy28;
        default:        goto yy3;
        }
yy3:
#line 371 "token.re"
{   YYPOS(0);
                        goto Document; 
                    }
#line 37 "<stdout>"
yy4:    yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '.':       goto yy21;
        default:        goto yy3;
        }
yy5:    ++YYCURSOR;
        goto yy6;
yy6:
#line 353 "token.re"
{   eat_comments( parser ); 
                        goto Header;
                    }
#line 51 "<stdout>"
yy7:    ++YYCURSOR;
        goto yy8;
yy8:
#line 357 "token.re"
{   SyckLevel *lvl = CURRENT_LEVEL();
                        ENSURE_YAML_IEND(lvl, -1);
                        YYPOS(0);
                        return 0; 
                    }
#line 61 "<stdout>"
yy9:    yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy18;
yy10:
#line 363 "token.re"
{   GOBBLE_UP_YAML_INDENT( doc_level, YYTOKEN );
                        goto Header; 
                    }
#line 70 "<stdout>"
yy11:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy17;
        default:        goto yy3;
        }
yy12:   ++YYCURSOR;
        yych = *YYCURSOR;
        goto yy16;
yy13:
#line 367 "token.re"
{   doc_level = YYCURSOR - YYLINEPTR;
                        goto Header;
                    }
#line 83 "<stdout>"
yy14:   yych = *++YYCURSOR;
        goto yy3;
yy15:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy16;
yy16:   switch(yych){
        case ' ':       goto yy15;
        default:        goto yy13;
        }
yy17:   yyaccept = 1;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy18;
yy18:   switch(yych){
        case '\n':      case ' ':       goto yy17;
        case '\r':      goto yy19;
        default:        goto yy10;
        }
yy19:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy17;
        default:        goto yy20;
        }
yy20:   YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 1: goto yy10;
        case 0: goto yy3;
        }
yy21:   yych = *++YYCURSOR;
        switch(yych){
        case '.':       goto yy22;
        default:        goto yy20;
        }
yy22:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy23;
        case '\r':      goto yy27;
        case ' ':       goto yy25;
        default:        goto yy20;
        }
yy23:   ++YYCURSOR;
        goto yy24;
yy24:
#line 339 "token.re"
{   SyckLevel *lvl = CURRENT_LEVEL();
                        if ( lvl->status == syck_lvl_header )
                        {
                            goto Header; 
                        }
                        else
                        {
                            ENSURE_YAML_IEND(lvl, -1);
                            YYPOS(0);
                            return 0; 
                        }
                        return 0; 
                    }
#line 147 "<stdout>"
yy25:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy26;
yy26:   switch(yych){
        case ' ':       goto yy25;
        default:        goto yy24;
        }
yy27:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy23;
        default:        goto yy20;
        }
yy28:   yych = *++YYCURSOR;
        switch(yych){
        case '-':       goto yy29;
        default:        goto yy20;
        }
yy29:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy30;
        case '\r':      goto yy34;
        case ' ':       goto yy32;
        default:        goto yy20;
        }
yy30:   ++YYCURSOR;
        goto yy31;
yy31:
#line 325 "token.re"
{   SyckLevel *lvl = CURRENT_LEVEL();
                        if ( lvl->status == syck_lvl_header )
                        {
                            YYPOS(3);
                            goto Directive; 
                        }
                        else
                        {
                            ENSURE_YAML_IEND(lvl, -1);
                            YYPOS(0);
                            return 0; 
                        }
                    }
#line 191 "<stdout>"
yy32:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy33;
yy33:   switch(yych){
        case ' ':       goto yy32;
        default:        goto yy31;
        }
yy34:   ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy30;
        default:        goto yy20;
        }
}
#line 375 "token.re"


Document:
    {
        SyckLevel *lvl = CURRENT_LEVEL();
        if ( lvl->status == syck_lvl_header )
        {
            lvl->status = syck_lvl_doc;
        }

        YYTOKEN = YYCURSOR;


#line 209 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy35;
yy36:   ++YYCURSOR;
yy35:
        if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy62;
        case '\n':      goto yy37;
        case '\r':      goto yy39;
        case ' ':       goto yy60;
        case '!':       goto yy51;
        case '"':       goto yy55;
        case '#':       goto yy58;
        case '&':       goto yy49;
        case '\'':      goto yy53;
        case '*':       goto yy50;
        case ',':       case ':':       goto yy47;
        case '-':       case '?':       goto yy48;
        case '>':       case '|':       goto yy57;
        case '[':       goto yy41;
        case ']':       case '}':       goto yy45;
        case '{':       goto yy43;
        default:        goto yy64;
        }
yy37:   yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy92;
yy38:
#line 389 "token.re"
{   /* Isolate spaces */
                        int indt_len;
                        GOBBLE_UP_YAML_INDENT( indt_len, YYTOKEN );
                        lvl = CURRENT_LEVEL();
                        doc_level = 0;

                        /* XXX: Comment lookahead */
                        if ( *YYCURSOR == '#' )
                        {
                            goto Document;
                        }

                        /* Ignore indentation inside inlines */
                        if ( lvl->status == syck_lvl_iseq || lvl->status == syck_lvl_imap )
                        {
                            goto Document;
                        }

                        /* Check for open indent */
                        ENSURE_YAML_IEND(lvl, indt_len);
                        ENSURE_YAML_IOPEN(lvl, indt_len, 0);
                        if ( indt_len == -1 )
                        {
                            return 0;
                        }
                        return YAML_INDENT;
                    }
#line 269 "<stdout>"
yy39:   ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy91;
        default:        goto yy40;
        }
yy40:
#line 493 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        goto Plain; 
                    }
#line 280 "<stdout>"
yy41:   ++YYCURSOR;
        goto yy42;
yy42:
#line 417 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        lvl = CURRENT_LEVEL();
                        ADD_LEVEL(lvl->spaces + 1, syck_lvl_iseq);
                        return YYTOKEN[0]; 
                    }
#line 290 "<stdout>"
yy43:   ++YYCURSOR;
        goto yy44;
yy44:
#line 423 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        lvl = CURRENT_LEVEL();
                        ADD_LEVEL(lvl->spaces + 1, syck_lvl_imap);
                        return YYTOKEN[0]; 
                    }
#line 300 "<stdout>"
yy45:   ++YYCURSOR;
        goto yy46;
yy46:
#line 429 "token.re"
{   POP_LEVEL();
                        return YYTOKEN[0]; 
                    }
#line 308 "<stdout>"
yy47:   yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy86;
        case '\r':      goto yy90;
        case ' ':       goto yy88;
        default:        goto yy40;
        }
yy48:   yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy81;
        case '\r':      goto yy85;
        case ' ':       goto yy83;
        default:        goto yy40;
        }
yy49:   yych = *++YYCURSOR;
        switch(yych){
        case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':       case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy78;
        default:        goto yy40;
        }
yy50:   yych = *++YYCURSOR;
        switch(yych){
        case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':       case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy75;
        default:        goto yy40;
        }
yy51:   ++YYCURSOR;
        goto yy52;
yy52:
#line 467 "token.re"
{   goto TransferMethod; }
#line 458 "<stdout>"
yy53:   ++YYCURSOR;
        goto yy54;
yy54:
#line 469 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        goto SingleQuote; }
#line 465 "<stdout>"
yy55:   ++YYCURSOR;
        goto yy56;
yy56:
#line 472 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        goto DoubleQuote; }
#line 472 "<stdout>"
yy57:   yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy70;
        case '\r':      goto yy74;
        case ' ':       goto yy72;
        case '+':       case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       goto yy67;
        default:        goto yy40;
        }
yy58:   ++YYCURSOR;
        goto yy59;
yy59:
#line 482 "token.re"
{   eat_comments( parser ); 
                        goto Document;
                    }
#line 498 "<stdout>"
yy60:   ++YYCURSOR;
        yych = *YYCURSOR;
        goto yy66;
yy61:
#line 486 "token.re"
{   goto Document; }
#line 504 "<stdout>"
yy62:   ++YYCURSOR;
        goto yy63;
yy63:
#line 488 "token.re"
{   ENSURE_YAML_IEND(lvl, -1);
                        YYPOS(0);
                        return 0; 
                    }
#line 513 "<stdout>"
yy64:   yych = *++YYCURSOR;
        goto yy40;
yy65:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy66;
yy66:   switch(yych){
        case ' ':       goto yy65;
        default:        goto yy61;
        }
yy67:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy68;
yy68:   switch(yych){
        case '\n':      goto yy70;
        case '\r':      goto yy74;
        case ' ':       goto yy72;
        case '+':       case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       goto yy67;
        default:        goto yy69;
        }
yy69:   YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy38;
        case 1: goto yy40;
        }
yy70:   ++YYCURSOR;
        goto yy71;
yy71:
#line 475 "token.re"
{   if ( is_newline( YYCURSOR - 1 ) ) 
                        {
                            YYCURSOR--;
                        }
                        goto ScalarBlock; 
                    }
#line 561 "<stdout>"
yy72:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy73;
yy73:   switch(yych){
        case ' ':       goto yy72;
        default:        goto yy71;
        }
yy74:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy70;
        default:        goto yy69;
        }
yy75:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy76;
yy76:   switch(yych){
        case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':       case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy75;
        default:        goto yy77;
        }
yy77:
#line 462 "token.re"
{   ENSURE_YAML_IOPEN(lvl, doc_level, 1);
                        sycklval->name = syck_strndup( YYTOKEN + 1, YYCURSOR - YYTOKEN - 1 );
                        return YAML_ALIAS;
                    }
#line 650 "<stdout>"
yy78:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy79;
yy79:   switch(yych){
        case '-':       case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':       case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy78;
        default:        goto yy80;
        }
yy80:
#line 451 "token.re"
{   sycklval->name = syck_strndup( YYTOKEN + 1, YYCURSOR - YYTOKEN - 1 );

                        /*
                         * Remove previous anchors of the same name.  Since the parser will likely
                         * construct deeper nodes first, we want those nodes to be placed in the
                         * queue for matching at a higher level of indentation.
                         */
                        syck_hdlr_remove_anchor(parser, sycklval->name);
                        return YAML_ANCHOR;
                    }
#line 731 "<stdout>"
yy81:   ++YYCURSOR;
        goto yy82;
yy82:
#line 437 "token.re"
{   ENSURE_YAML_IOPEN(lvl, YYTOKEN - YYLINEPTR, 1);
                        FORCE_NEXT_TOKEN(YAML_IOPEN);
                        if ( *YYCURSOR == '#' || is_newline( YYCURSOR ) || is_newline( YYCURSOR - 1 ) )
                        {
                            YYCURSOR--; 
                            ADD_LEVEL((YYTOKEN + 1) - YYLINEPTR, syck_lvl_doc);
                        }
                        else /* spaces followed by content uses the space as indentation */
                        {
                            ADD_LEVEL(YYCURSOR - YYLINEPTR, syck_lvl_doc);
                        }
                        return YYTOKEN[0]; 
                    }
#line 749 "<stdout>"
yy83:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy84;
yy84:   switch(yych){
        case ' ':       goto yy83;
        default:        goto yy82;
        }
yy85:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy81;
        default:        goto yy69;
        }
yy86:   ++YYCURSOR;
        goto yy87;
yy87:
#line 433 "token.re"
{   YYPOS(1); 
                        return YYTOKEN[0]; 
                    }
#line 771 "<stdout>"
yy88:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy89;
yy89:   switch(yych){
        case ' ':       goto yy88;
        default:        goto yy87;
        }
yy90:   yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy86;
        default:        goto yy69;
        }
yy91:   yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy92;
yy92:   switch(yych){
        case '\n':      case ' ':       goto yy91;
        case '\r':      goto yy93;
        default:        goto yy38;
        }
yy93:   ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy91;
        default:        goto yy69;
        }
}
#line 497 "token.re"

    }

Directive:
    {
        YYTOKTMP = YYCURSOR;


#line 807 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy94;
yy95:   ++YYCURSOR;
yy94:
        if((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy96;
        case ' ':       goto yy99;
        case '%':       goto yy97;
        default:        goto yy101;
        }
yy96:   YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy98;
        }
yy97:   yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '.':
        case '/':
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':
        case ':':
        case ';':
        case '<':
        case '=':
        case '>':
        case '?':
        case '@':
        case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':
        case '[':
        case '\\':
        case ']':
        case '^':
        case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy104;
        default:        goto yy98;
        }
yy98:
#line 510 "token.re"
{   YYCURSOR = YYTOKTMP;
                        return YAML_DOCSEP;
                    }
#line 911 "<stdout>"
yy99:   ++YYCURSOR;
        yych = *YYCURSOR;
        goto yy103;
yy100:
#line 508 "token.re"
{   goto Directive; }
#line 917 "<stdout>"
yy101:  yych = *++YYCURSOR;
        goto yy98;
yy102:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy103;
yy103:  switch(yych){
        case ' ':       goto yy102;
        default:        goto yy100;
        }
yy104:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy105;
yy105:  switch(yych){
        case '.':
        case '/':
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case ';':
        case '<':
        case '=':
        case '>':
        case '?':
        case '@':
        case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':
        case '[':
        case '\\':
        case ']':
        case '^':
        case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy104;
        case ':':       goto yy106;
        default:        goto yy96;
        }
yy106:  yych = *++YYCURSOR;
        switch(yych){
        case '.':
        case '/':
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':
        case ':':
        case ';':
        case '<':
        case '=':
        case '>':
        case '?':
        case '@':
        case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':
        case '[':
        case '\\':
        case ']':
        case '^':
        case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy107;
        default:        goto yy96;
        }
yy107:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy108;
yy108:  switch(yych){
        case '.':
        case '/':
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':
        case ':':
        case ';':
        case '<':
        case '=':
        case '>':
        case '?':
        case '@':
        case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':
        case 'G':
        case 'H':
        case 'I':
        case 'J':
        case 'K':
        case 'L':
        case 'M':
        case 'N':
        case 'O':
        case 'P':
        case 'Q':
        case 'R':
        case 'S':
        case 'T':
        case 'U':
        case 'V':
        case 'W':
        case 'X':
        case 'Y':
        case 'Z':
        case '[':
        case '\\':
        case ']':
        case '^':
        case '_':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':
        case 'g':
        case 'h':
        case 'i':
        case 'j':
        case 'k':
        case 'l':
        case 'm':
        case 'n':
        case 'o':
        case 'p':
        case 'q':
        case 'r':
        case 's':
        case 't':
        case 'u':
        case 'v':
        case 'w':
        case 'x':
        case 'y':
        case 'z':       goto yy107;
        default:        goto yy109;
        }
yy109:
#line 506 "token.re"
{   goto Directive; }
#line 1176 "<stdout>"
}
#line 513 "token.re"


    }

Plain:
    {
        int qidx = 0;
        int qcapa = 100;
        char *qstr = S_ALLOC_N( char, qcapa );
        SyckLevel *plvl;
        int parentIndent;

        YYCURSOR = YYTOKEN;
        plvl = CURRENT_LEVEL();
        GET_TRUE_YAML_INDENT(parentIndent);

Plain2: 
        YYTOKEN = YYCURSOR;

Plain3:


#line 1180 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy110;
yy111:  ++YYCURSOR;
yy110:
        if((YYLIMIT - YYCURSOR) < 3) YYFILL(3);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy124;
        case '\n':      goto yy112;
        case '\r':      goto yy114;
        case ' ':       goto yy122;
        case ',':       goto yy117;
        case ':':       goto yy116;
        case ']':       goto yy120;
        case '}':       goto yy118;
        default:        goto yy126;
        }
yy112:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy141;
yy113:
#line 536 "token.re"
{   int indt_len, nl_count = 0;
                        SyckLevel *lvl;
                        char *tok = YYTOKEN;
                        GOBBLE_UP_YAML_INDENT( indt_len, tok );
                        lvl = CURRENT_LEVEL();

                        if ( indt_len <= parentIndent )
                        {
                            RETURN_IMPLICIT();
                        }

                        while ( YYTOKEN < YYCURSOR )
                        {
                            int nl_len = 0;
                            if ( nl_len = newline_len( YYTOKEN++ ) )
                            {
                                nl_count++;
                                YYTOKEN += nl_len - 1;
                            }
                        }
                        if ( nl_count <= 1 )
                        {
                            QUOTECAT(qstr, qcapa, qidx, ' ');
                        }
                        else
                        {
                            int i;
                            for ( i = 0; i < nl_count - 1; i++ )
                            {
                                QUOTECAT(qstr, qcapa, qidx, '\n');
                            }
                        }

                        goto Plain2; 
                    }
#line 1240 "<stdout>"
yy114:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy140;
        default:        goto yy115;
        }
yy115:
#line 615 "token.re"
{   QUOTECATS(qstr, qcapa, qidx, YYTOKEN, YYCURSOR - YYTOKEN);
                        goto Plain2;
                    }
#line 1251 "<stdout>"
yy116:  yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy135;
        case '\r':      goto yy139;
        case ' ':       goto yy137;
        default:        goto yy115;
        }
yy117:  yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy129;
        case '\r':      goto yy133;
        case ' ':       goto yy131;
        default:        goto yy115;
        }
yy118:  ++YYCURSOR;
        goto yy119;
yy119:
#line 585 "token.re"
{   if ( plvl->status != syck_lvl_imap )
                        {
                            PLAIN_NOT_INL();
                        }
                        else
                        {
                            PLAIN_IS_INL();
                        }
                        RETURN_IMPLICIT();
                    }
#line 1282 "<stdout>"
yy120:  ++YYCURSOR;
        goto yy121;
yy121:
#line 596 "token.re"
{   if ( plvl->status != syck_lvl_iseq )
                        {
                            PLAIN_NOT_INL();
                        }
                        else
                        {
                            PLAIN_IS_INL();
                        }
                        RETURN_IMPLICIT();
                    }
#line 1297 "<stdout>"
yy122:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '#':       goto yy127;
        default:        goto yy123;
        }
yy123:
#line 613 "token.re"
{   goto Plain3; }
#line 1306 "<stdout>"
yy124:  ++YYCURSOR;
        goto yy125;
yy125:
#line 611 "token.re"
{   RETURN_IMPLICIT(); }
#line 1312 "<stdout>"
yy126:  yych = *++YYCURSOR;
        goto yy115;
yy127:  ++YYCURSOR;
        goto yy128;
yy128:
#line 607 "token.re"
{   eat_comments( parser ); 
                        RETURN_IMPLICIT();
                    }
#line 1322 "<stdout>"
yy129:  ++YYCURSOR;
        goto yy130;
yy130:
#line 574 "token.re"
{   if ( plvl->status != syck_lvl_iseq && plvl->status != syck_lvl_imap )
                        {
                            PLAIN_NOT_INL();
                        }
                        else
                        {
                            PLAIN_IS_INL();
                        }
                        RETURN_IMPLICIT();
                    }
#line 1337 "<stdout>"
yy131:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy132;
yy132:  switch(yych){
        case ' ':       goto yy131;
        default:        goto yy130;
        }
yy133:  yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy129;
        default:        goto yy134;
        }
yy134:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy113;
        case 1: goto yy115;
        }
yy135:  ++YYCURSOR;
        goto yy136;
yy136:
#line 572 "token.re"
{   RETURN_IMPLICIT(); }
#line 1362 "<stdout>"
yy137:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy138;
yy138:  switch(yych){
        case ' ':       goto yy137;
        default:        goto yy136;
        }
yy139:  yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy135;
        default:        goto yy134;
        }
yy140:  yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy141;
yy141:  switch(yych){
        case '\n':      case ' ':       goto yy140;
        case '\r':      goto yy142;
        default:        goto yy113;
        }
yy142:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy140;
        default:        goto yy134;
        }
}
#line 619 "token.re"

    }

SingleQuote:
    {
        int qidx = 0;
        int qcapa = 100;
        char *qstr = S_ALLOC_N( char, qcapa );

SingleQuote2:
        YYTOKEN = YYCURSOR;


#line 1398 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy143;
yy144:  ++YYCURSOR;
yy143:
        if((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy151;
        case '\n':      goto yy145;
        case '\r':      goto yy147;
        case '\'':      goto yy149;
        default:        goto yy152;
        }
yy145:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy156;
yy146:
#line 633 "token.re"
{   int indt_len;
                        int nl_count = 0;
                        SyckLevel *lvl;
                        GOBBLE_UP_YAML_INDENT( indt_len, YYTOKEN );
                        lvl = CURRENT_LEVEL();

                        if ( lvl->status != syck_lvl_str )
                        {
                            ADD_LEVEL( indt_len, syck_lvl_str );
                        }
                        else if ( indt_len < lvl->spaces )
                        {
                            /* Error! */
                        }

                        while ( YYTOKEN < YYCURSOR )
                        {
                            int nl_len = 0;
                            if ( nl_len = newline_len( YYTOKEN++ ) )
                            {
                                nl_count++;
                                YYTOKEN += nl_len - 1;
                            }
                        }
                        if ( nl_count <= 1 )
                        {
                            QUOTECAT(qstr, qcapa, qidx, ' ');
                        }
                        else
                        {
                            int i;
                            for ( i = 0; i < nl_count - 1; i++ )
                            {
                                QUOTECAT(qstr, qcapa, qidx, '\n');
                            }
                        }

                        goto SingleQuote2; 
                    }
#line 1458 "<stdout>"
yy147:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy155;
        default:        goto yy148;
        }
yy148:
#line 700 "token.re"
{   QUOTECAT(qstr, qcapa, qidx, *(YYCURSOR - 1)); 
                        goto SingleQuote2; 
                    }
#line 1469 "<stdout>"
yy149:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\'':      goto yy153;
        default:        goto yy150;
        }
yy150:
#line 677 "token.re"
{   SyckLevel *lvl;
                        SyckNode *n = syck_alloc_str();
                        lvl = CURRENT_LEVEL();

                        if ( lvl->status == syck_lvl_str )
                        {
                            POP_LEVEL();
                        }
                        if ( ((SyckParser *)parser)->taguri_expansion == 1 )
                        {
                            n->type_id = syck_taguri( YAML_DOMAIN, "str", 3 );
                        }
                        else
                        {
                            n->type_id = syck_strndup( "str", 3 );
                        }
                        n->data.str->ptr = qstr;
                        n->data.str->len = qidx;
                        n->data.str->style = scalar_1quote;
                        sycklval->nodeData = n;
                        return YAML_PLAIN; 
                    }
#line 1499 "<stdout>"
yy151:  yych = *++YYCURSOR;
        goto yy150;
yy152:  yych = *++YYCURSOR;
        goto yy148;
yy153:  ++YYCURSOR;
        goto yy154;
yy154:
#line 673 "token.re"
{   QUOTECAT(qstr, qcapa, qidx, '\'');
                        goto SingleQuote2; 
                    }
#line 1511 "<stdout>"
yy155:  yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy156;
yy156:  switch(yych){
        case '\n':      case ' ':       goto yy155;
        case '\r':      goto yy157;
        default:        goto yy146;
        }
yy157:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy155;
        default:        goto yy158;
        }
yy158:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy146;
        }
}
#line 704 "token.re"


    }


DoubleQuote:
    {
        int keep_nl = 1;
        int qidx = 0;
        int qcapa = 100;
        char *qstr = S_ALLOC_N( char, qcapa );

DoubleQuote2:
        YYTOKEN = YYCURSOR;



#line 1537 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy159;
yy160:  ++YYCURSOR;
yy159:
        if((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy166;
        case '\n':      goto yy161;
        case '\r':      goto yy163;
        case '"':       goto yy168;
        case '\\':      goto yy165;
        default:        goto yy169;
        }
yy161:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy183;
yy162:
#line 722 "token.re"
{   int indt_len;
                        int nl_count = 0;
                        SyckLevel *lvl;
                        GOBBLE_UP_YAML_INDENT( indt_len, YYTOKEN );
                        lvl = CURRENT_LEVEL();

                        if ( lvl->status != syck_lvl_str )
                        {
                            ADD_LEVEL( indt_len, syck_lvl_str );
                        }
                        else if ( indt_len < lvl->spaces )
                        {
                            /* FIXME */
                        }

                        if ( keep_nl == 1 )
                        {
                            while ( YYTOKEN < YYCURSOR )
                            {
                                int nl_len = 0;
                                if ( nl_len = newline_len( YYTOKEN++ ) )
                                {
                                    nl_count++;
                                    YYTOKEN += nl_len - 1;
                                }
                            }
                            if ( nl_count <= 1 )
                            {
                                QUOTECAT(qstr, qcapa, qidx, ' ');
                            }
                            else
                            {
                                int i;
                                for ( i = 0; i < nl_count - 1; i++ )
                                {
                                    QUOTECAT(qstr, qcapa, qidx, '\n');
                                }
                            }
                        }

                        keep_nl = 1;
                        goto DoubleQuote2; 
                    }
#line 1602 "<stdout>"
yy163:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy182;
        default:        goto yy164;
        }
yy164:
#line 808 "token.re"
{   QUOTECAT(qstr, qcapa, qidx, *(YYCURSOR - 1)); 
                        goto DoubleQuote2; 
                    }
#line 1613 "<stdout>"
yy165:  yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '\n':      goto yy173;
        case '\r':      goto yy175;
        case ' ':       goto yy170;
        case '"':       case '0':       case '\\':      case 'a':
        case 'b':       case 'e':
        case 'f':       case 'n':       case 'r':       case 't':       case 'v':       goto yy177;
        case 'x':       goto yy176;
        default:        goto yy164;
        }
yy166:  ++YYCURSOR;
        goto yy167;
yy167:
#line 785 "token.re"
{   SyckLevel *lvl;
                        SyckNode *n = syck_alloc_str();
                        lvl = CURRENT_LEVEL();

                        if ( lvl->status == syck_lvl_str )
                        {
                            POP_LEVEL();
                        }
                        if ( ((SyckParser *)parser)->taguri_expansion == 1 )
                        {
                            n->type_id = syck_taguri( YAML_DOMAIN, "str", 3 );
                        }
                        else
                        {
                            n->type_id = syck_strndup( "str", 3 );
                        }
                        n->data.str->ptr = qstr;
                        n->data.str->len = qidx;
                        n->data.str->style = scalar_2quote;
                        sycklval->nodeData = n;
                        return YAML_PLAIN; 
                    }
#line 1652 "<stdout>"
yy168:  yych = *++YYCURSOR;
        goto yy167;
yy169:  yych = *++YYCURSOR;
        goto yy164;
yy170:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy171;
yy171:  switch(yych){
        case '\n':      goto yy173;
        case '\r':      goto yy175;
        case ' ':       goto yy170;
        default:        goto yy172;
        }
yy172:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy162;
        case 1: goto yy164;
        }
yy173:  ++YYCURSOR;
        goto yy174;
yy174:
#line 780 "token.re"
{   keep_nl = 0;
                        YYCURSOR--;
                        goto DoubleQuote2; 
                    }
#line 1681 "<stdout>"
yy175:  yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy173;
        default:        goto yy172;
        }
yy176:  yych = *++YYCURSOR;
        switch(yych){
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':       goto yy179;
        default:        goto yy172;
        }
yy177:  ++YYCURSOR;
        goto yy178;
yy178:
#line 766 "token.re"
{   char ch = *( YYCURSOR - 1 );
                        QUOTECAT(qstr, qcapa, qidx, escape_seq( ch ));
                        goto DoubleQuote2; 
                    }
#line 1719 "<stdout>"
yy179:  yych = *++YYCURSOR;
        switch(yych){
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':       goto yy180;
        default:        goto yy172;
        }
yy180:  ++YYCURSOR;
        goto yy181;
yy181:
#line 771 "token.re"
{   long ch;
                        char *chr_text = syck_strndup( YYTOKEN, 4 );
                        chr_text[0] = '0';
                        ch = strtol( chr_text, NULL, 16 );
                        free( chr_text );
                        QUOTECAT(qstr, qcapa, qidx, ch);
                        goto DoubleQuote2; 
                    }
#line 1756 "<stdout>"
yy182:  yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy183;
yy183:  switch(yych){
        case '\n':      case ' ':       goto yy182;
        case '\r':      goto yy184;
        default:        goto yy162;
        }
yy184:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy182;
        default:        goto yy172;
        }
}
#line 812 "token.re"

    }

TransferMethod:
    {
        int qidx = 0;
        int qcapa = 100;
        char *qstr = S_ALLOC_N( char, qcapa );

TransferMethod2:
        YYTOKTMP = YYCURSOR;


#line 1778 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy185;
yy186:  ++YYCURSOR;
yy185:
        if((YYLIMIT - YYCURSOR) < 4) YYFILL(4);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy187;
        case '\n':      goto yy189;
        case '\r':      goto yy191;
        case ' ':       goto yy190;
        case '\\':      goto yy193;
        default:        goto yy194;
        }
yy187:  ++YYCURSOR;
        goto yy188;
yy188:
#line 826 "token.re"
{   SyckLevel *lvl;
                        YYCURSOR = YYTOKTMP;
                        if ( YYCURSOR == YYTOKEN + 1 )
                        {
                            free( qstr );
                            return YAML_ITRANSFER;
                        }

                        lvl = CURRENT_LEVEL();

                        /*
                         * URL Prefixing
                         */
                        if ( *qstr == '^' )
                        {
                            sycklval->name = S_ALLOC_N( char, qidx + strlen( lvl->domain ) );
                            sycklval->name[0] = '\0';
                            strcat( sycklval->name, lvl->domain );
                            strncat( sycklval->name, qstr + 1, qidx - 1 );
                            free( qstr );
                        }
                        else
                        {
                            char *carat = qstr;
                            char *qend = qstr + qidx;
                            while ( (++carat) < qend )
                            {
                                if ( *carat == '^' )
                                    break;
                            }

                            if ( carat < qend )
                            {
                                free( lvl->domain );
                                lvl->domain = syck_strndup( qstr, carat - qstr );
                                sycklval->name = S_ALLOC_N( char, ( qend - carat ) + strlen( lvl->domain ) );
                                sycklval->name[0] = '\0';
                                strcat( sycklval->name, lvl->domain );
                                strncat( sycklval->name, carat + 1, ( qend - carat ) - 1 );
                                free( qstr );
                            }
                            else
                            {
                                sycklval->name = qstr;
                            }
                        }

                        return YAML_TRANSFER; 
                    }
#line 1848 "<stdout>"
yy189:  yych = *++YYCURSOR;
        goto yy188;
yy190:  yych = *++YYCURSOR;
        goto yy203;
yy191:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy187;
        default:        goto yy192;
        }
yy192:
#line 893 "token.re"
{   QUOTECAT(qstr, qcapa, qidx, *(YYCURSOR - 1)); 
                        goto TransferMethod2;
                    }
#line 1863 "<stdout>"
yy193:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '"':       case '0':       case '\\':      case 'a':
        case 'b':       case 'e':
        case 'f':       case 'n':       case 'r':       case 't':       case 'v':       goto yy197;
        case 'x':       goto yy195;
        default:        goto yy192;
        }
yy194:  yych = *++YYCURSOR;
        goto yy192;
yy195:  yych = *++YYCURSOR;
        switch(yych){
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':       goto yy199;
        default:        goto yy196;
        }
yy196:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy192;
        }
yy197:  ++YYCURSOR;
        goto yy198;
yy198:
#line 879 "token.re"
{  char ch = *( YYCURSOR - 1 );
                        QUOTECAT(qstr, qcapa, qidx, escape_seq( ch ));
                        goto TransferMethod2;
                    }
#line 1911 "<stdout>"
yy199:  yych = *++YYCURSOR;
        switch(yych){
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':       case 'A':
        case 'B':
        case 'C':
        case 'D':
        case 'E':
        case 'F':       case 'a':
        case 'b':
        case 'c':
        case 'd':
        case 'e':
        case 'f':       goto yy200;
        default:        goto yy196;
        }
yy200:  ++YYCURSOR;
        goto yy201;
yy201:
#line 884 "token.re"
{   long ch;
                        char *chr_text = syck_strndup( YYTOKTMP, 4 );
                        chr_text[0] = '0';
                        ch = strtol( chr_text, NULL, 16 );
                        free( chr_text );
                        QUOTECAT(qstr, qcapa, qidx, ch);
                        goto TransferMethod2;
                    }
#line 1948 "<stdout>"
yy202:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy203;
yy203:  switch(yych){
        case ' ':       goto yy202;
        default:        goto yy188;
        }
}
#line 898 "token.re"

    }

ScalarBlock:
    {
        int qidx = 0;
        int qcapa = 100;
        char *qstr = S_ALLOC_N( char, qcapa );
        int blockType = 0;
        int nlDoWhat = 0;
        int lastIndent = 0;
        int forceIndent = -1;
        char *yyt = YYTOKEN;
        SyckLevel *lvl = CURRENT_LEVEL();
        int parentIndent;
        GET_TRUE_YAML_INDENT(parentIndent);

        switch ( *yyt )
        {
            case '|': blockType = BLOCK_LIT; break;
            case '>': blockType = BLOCK_FOLD; break;
        }

        while ( ++yyt <= YYCURSOR )
        {
            if ( *yyt == '-' )
            {
                nlDoWhat = NL_CHOMP;
            }
            else if ( *yyt == '+' )
            {
                nlDoWhat = NL_KEEP;
            }
            else if ( isdigit( *yyt ) )
            {
                forceIndent = strtol( yyt, NULL, 10 ) + parentIndent;
            }
        }

        qstr[0] = '\0';
        YYTOKEN = YYCURSOR;

ScalarBlock2:
        YYTOKEN = YYCURSOR;


#line 1961 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy204;
yy205:  ++YYCURSOR;
yy204:
        if((YYLIMIT - YYCURSOR) < 5) YYFILL(5);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy212;
        case '\n':      goto yy206;
        case '\r':      goto yy208;
        case '#':       goto yy210;
        case '-':       goto yy214;
        default:        goto yy215;
        }
yy206:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy225;
yy207:
#line 945 "token.re"
{   char *pacer;
                        char *tok = YYTOKEN;
                        int indt_len = 0, nl_count = 0, fold_nl = 0, nl_begin = 0;
                        GOBBLE_UP_YAML_INDENT( indt_len, tok );
                        lvl = CURRENT_LEVEL();

                        if ( indt_len > parentIndent && lvl->status != syck_lvl_block )
                        {
                            int new_spaces = forceIndent > 0 ? forceIndent : indt_len;
                            ADD_LEVEL( new_spaces, syck_lvl_block );
                            lastIndent = indt_len - new_spaces;
                            nl_begin = 1;
                            lvl = CURRENT_LEVEL();
                        }
                        else if ( lvl->status != syck_lvl_block )
                        {
                            YYCURSOR = YYTOKEN;
                            RETURN_YAML_BLOCK();
                        }

                        /*
                         * Fold only in the event of two lines being on the leftmost
                         * indentation.
                         */
                        if ( blockType == BLOCK_FOLD && lastIndent == 0 && ( indt_len - lvl->spaces ) == 0 )
                        {
                            fold_nl = 1;
                        }

                        pacer = YYTOKEN;
                        while ( pacer < YYCURSOR )
                        {
                            int nl_len = 0;
                            if ( nl_len = newline_len( pacer++ ) )
                            {
                                nl_count++;
                                pacer += nl_len - 1;
                            }
                        }

                        if ( fold_nl == 1 || nl_begin == 1 )
                        {
                            nl_count--;
                        }

                        if ( nl_count < 1 && nl_begin == 0 )
                        {
                            QUOTECAT(qstr, qcapa, qidx, ' ');
                        }
                        else
                        {
                            int i;
                            for ( i = 0; i < nl_count; i++ )
                            {
                                QUOTECAT(qstr, qcapa, qidx, '\n');
                            }
                        }

                        lastIndent = indt_len - lvl->spaces;
                        YYCURSOR -= lastIndent;

                        if ( indt_len < lvl->spaces )
                        {
                            POP_LEVEL();
                            YYCURSOR = YYTOKEN;
                            RETURN_YAML_BLOCK();
                        }
                        goto ScalarBlock2;
                    }
#line 2052 "<stdout>"
yy208:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy224;
        default:        goto yy209;
        }
yy209:
#line 1054 "token.re"
{   QUOTECAT(qstr, qcapa, qidx, *YYTOKEN);
                        goto ScalarBlock2;
                    }
#line 2063 "<stdout>"
yy210:  ++YYCURSOR;
        goto yy211;
yy211:
#line 1016 "token.re"
{   lvl = CURRENT_LEVEL();
                        if ( lvl->status != syck_lvl_block )
                        {
                            eat_comments( parser );
                            YYTOKEN = YYCURSOR;
                        }
                        else
                        {
                            QUOTECAT(qstr, qcapa, qidx, *YYTOKEN);
                        }
                        goto ScalarBlock2;
                    }
#line 2080 "<stdout>"
yy212:  ++YYCURSOR;
        goto yy213;
yy213:
#line 1030 "token.re"
{   YYCURSOR--;
                        POP_LEVEL();
                        RETURN_YAML_BLOCK(); 
                    }
#line 2089 "<stdout>"
yy214:  yyaccept = 1;
        yych = *(YYMARKER = ++YYCURSOR);
        switch(yych){
        case '-':       goto yy216;
        default:        goto yy209;
        }
yy215:  yych = *++YYCURSOR;
        goto yy209;
yy216:  yych = *++YYCURSOR;
        switch(yych){
        case '-':       goto yy218;
        default:        goto yy217;
        }
yy217:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy207;
        case 1: goto yy209;
        }
yy218:  yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy219;
        case '\r':      goto yy223;
        case ' ':       goto yy221;
        default:        goto yy217;
        }
yy219:  ++YYCURSOR;
        goto yy220;
yy220:
#line 1035 "token.re"
{   if ( YYTOKEN == YYLINEPTR )
                        {
                            if ( blockType == BLOCK_FOLD && qidx > 0 )
                            {
                                qidx -= 1;
                            }
                            QUOTECAT(qstr, qcapa, qidx, '\n');
                            POP_LEVEL();
                            YYCURSOR = YYTOKEN;
                            RETURN_YAML_BLOCK();
                        }
                        else
                        {
                            QUOTECAT(qstr, qcapa, qidx, *YYTOKEN);
                            YYCURSOR = YYTOKEN + 1;
                            goto ScalarBlock2;
                        }
                    }
#line 2137 "<stdout>"
yy221:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy222;
yy222:  switch(yych){
        case ' ':       goto yy221;
        default:        goto yy220;
        }
yy223:  yych = *++YYCURSOR;
        switch(yych){
        case '\n':      goto yy219;
        default:        goto yy217;
        }
yy224:  yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy225;
yy225:  switch(yych){
        case '\n':      case ' ':       goto yy224;
        case '\r':      goto yy226;
        default:        goto yy207;
        }
yy226:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy224;
        default:        goto yy217;
        }
}
#line 1059 "token.re"

    }

    return 0;

}

void
eat_comments( SyckParser *parser )
{
Comment:
    {
        YYTOKEN = YYCURSOR;


#line 2173 "<stdout>"
{
        YYCTYPE yych;
        unsigned int yyaccept;
        goto yy227;
yy228:  ++YYCURSOR;
yy227:
        if((YYLIMIT - YYCURSOR) < 2) YYFILL(2);
        yych = *YYCURSOR;
        switch(yych){
        case '\000':    goto yy229;
        case '\n':      goto yy231;
        case '\r':      goto yy232;
        default:        goto yy234;
        }
yy229:  ++YYCURSOR;
        goto yy230;
yy230:
#line 1075 "token.re"
{   YYCURSOR = YYTOKEN;
                        return;
                    }
#line 2195 "<stdout>"
yy231:  yyaccept = 0;
        yych = *(YYMARKER = ++YYCURSOR);
        goto yy236;
yy232:  ++YYCURSOR;
        switch((yych = *YYCURSOR)) {
        case '\n':      goto yy235;
        default:        goto yy233;
        }
yy233:
#line 1079 "token.re"
{   goto Comment; 
                    }
#line 2208 "<stdout>"
yy234:  yych = *++YYCURSOR;
        goto yy233;
yy235:  yyaccept = 0;
        YYMARKER = ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        goto yy236;
yy236:  switch(yych){
        case '\n':      goto yy235;
        case '\r':      goto yy237;
        default:        goto yy230;
        }
yy237:  ++YYCURSOR;
        if(YYLIMIT == YYCURSOR) YYFILL(1);
        yych = *YYCURSOR;
        switch(yych){
        case '\n':      goto yy235;
        default:        goto yy238;
        }
yy238:  YYCURSOR = YYMARKER;
        switch(yyaccept){
        case 0: goto yy230;
        }
}
#line 1082 "token.re"


    }

}

char
escape_seq( char ch )
{
    switch ( ch )
    {
        case '0': return '\0';
        case 'a': return 7;
        case 'b': return '\010';
        case 'e': return '\033';
        case 'f': return '\014';
        case 'n': return '\n';
        case 'r': return '\015';
        case 't': return '\t';
        case 'v': return '\013';
        default: return ch;
    }
}

int
is_newline( char *ptr )
{
    return newline_len( ptr );
}

int
newline_len( char *ptr )
{
    if ( *ptr == '\n' )
        return 1;
    
    if ( *ptr == '\r' && *( ptr + 1 ) == '\n' )
        return 2;

    return 0;
}

int 
syckwrap()
{
    return 1;
}

void 
syckerror( char *msg )
{
    if ( syck_parser_ptr->error_handler == NULL )
        syck_parser_ptr->error_handler = syck_default_error_handler;

    syck_parser_ptr->root = syck_parser_ptr->root_on_error;
    (syck_parser_ptr->error_handler)(syck_parser_ptr, msg);
}

